@@ -5,10 +5,13 @@
 import pytest
 from support import InstanceTestCase
 
+import minizinc
 from minizinc.error import (
-    MiniZincAssertionError,
-    MiniZincSyntaxError,
-    MiniZincTypeError,
+    AssertionError,
+    EvaluationError,
+    MiniZincError,
+    SyntaxError,
+    TypeError,
 )
 
 
@@ -22,12 +25,13 @@ class AssertionTest(InstanceTestCase):
     """
 
     def test_assertion_error(self):
-        with pytest.raises(MiniZincAssertionError, match="a not decreasing") as error:
+        with pytest.raises(AssertionError, match="a not decreasing") as error:
             self.instance.solve()
         loc = error.value.location
         assert str(loc.file).endswith(".mzn")
-        assert loc.line == 3
-        assert loc.columns == (0, 0)
+        assert loc.lines == (3, 3)
+        if minizinc.default_driver.parsed_version >= (2, 6, 0):
+            assert loc.columns == (27, 62)
 
 
 class TypeErrorTest(InstanceTestCase):
@@ -37,13 +41,11 @@ class TypeErrorTest(InstanceTestCase):
     """
 
     def test_type_error(self):
-        with pytest.raises(
-            MiniZincTypeError, match="No matching operator found"
-        ) as error:
+        with pytest.raises(TypeError, match="No matching operator found") as error:
             self.instance.solve()
         loc = error.value.location
         assert str(loc.file).endswith(".mzn")
-        assert loc.line == 3
+        assert loc.lines == (3, 3)
         assert loc.columns == (20, 26)
 
 
@@ -51,11 +53,44 @@ class SyntaxErrorTest(InstanceTestCase):
     code = "constrain true;"
 
     def test_syntax_error(self):
-        with pytest.raises(
-            MiniZincSyntaxError, match="unexpected bool literal"
-        ) as error:
+        with pytest.raises(SyntaxError, match="unexpected bool literal") as error:
             self.instance.solve()
         loc = error.value.location
         assert str(loc.file).endswith(".mzn")
-        assert loc.line == 1
+        assert loc.lines == (1, 1)
         assert loc.columns == (11, 14)
+
+
+class EvaluationErrorTest(InstanceTestCase):
+    def test_infinite_recursion(self):
+        self.instance.add_string(
+            """
+test overflow(int: x) = overflow(x + 1);
+int: cause_overflow = overflow(1);
+"""
+        )
+
+        with pytest.raises(
+            MiniZincError,
+            match="stack overflow"
+            if minizinc.default_driver.parsed_version >= (2, 6, 0)
+            else "non-zero exit code",
+        ):
+            self.instance.solve()
+
+    def test_evaluation_error(self):
+        self.instance.add_string(
+            """
+array [1..3] of int: a = [1, 2, 3, 4];
+
+solve satisfy;
+"""
+        )
+        with pytest.raises(EvaluationError, match="index set") as error:
+            self.instance.solve()
+        loc = error.value.location
+        print(loc)
+        assert str(loc.file).endswith(".mzn")
+        assert loc.lines == (2, 2)
+        if minizinc.default_driver.parsed_version >= (2, 6, 0):
+            assert loc.columns == (1, 22)
